%global with_debug 1

%if 0%{?with_debug}
%global _find_debuginfo_dwz_opts %{nil}
%global _dwz_low_mem_die_limit 0
%else
%global debug_package   %{nil}
%endif

%if 0%{?rhel} <= 7 && ! 0%{?fedora}
%define gominver 13
%define gobuild(o:) scl enable go-toolset-1.%{gominver} -- go build -buildmode pie -compiler gc -tags="rpm_crashtraceback ${BUILDTAGS:-}" -ldflags "${LDFLAGS:-} -linkmode=external -compressdwarf=false -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \\n') -extldflags '%__global_ldflags'" -a -v -x %{?**};
%else
%define gobuild(o:) go build -buildmode pie -compiler gc -tags="rpm_crashtraceback libtrust_openssl ${BUILDTAGS:-}" -ldflags "${LDFLAGS:-} -linkmode=external -compressdwarf=false -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \\n') -extldflags '%__global_ldflags'" -a -v -x %{?**};
%endif

%global provider github
%global provider_tld com
%global project kubernetes-sigs
%global repo cri-tools
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path %{provider_prefix}
%global git0 https://%{import_path}
%global commit0 3c91ebf539bd2035d60813386f5b1f023937423f
%global shortcommit0 %(c=%{commit0}; echo ${c:0:7})

Name: %{repo}
Version: 1.28.0
Release: 3.2%{?dist}
Summary: CLI and validation tools for Container Runtime Interface
License: ASL 2.0
URL: %{git0}
Source0: %{git0}/archive/%{commit0}/%{name}-%{shortcommit0}.tar.gz
Patch0: snyk.diff
%if 0%{?rhel} <= 7 && ! 0%{?fedora}
BuildRequires: go-toolset-1.%{gominver}
%else
BuildRequires: golang
%endif
BuildRequires: glibc-static
BuildRequires: git
BuildRequires: go-md2man
Provides: crictl = %{version}-%{release}

%description
%{summary}

%prep
%autosetup -Sgit -n %{name}-%{commit0}

%build
mkdir _build
pushd _build
mkdir -p src/%{provider}.%{provider_tld}/%{project}
ln -s ../../../../ src/%{import_path}
popd
ln -s vendor src
export GOPATH=$(pwd)/_build:$(pwd)
export GO111MODULE=off
export LDFLAGS+=" -X %{import_path}/pkg/version.Version=%version"
export CGO_CFLAGS="%{optflags} -D_GNU_SOURCE -D_LARGEFILE_SOURCE -D_LARGEFILE64_SOURCE -D_FILE_OFFSET_BITS=64"

GOPATH=$GOPATH %gobuild -o bin/crictl %{import_path}/cmd/crictl
go-md2man -in docs/crictl.md -out docs/crictl.1
bin/crictl completion > docs/crictl-completions

%install
# install binaries
install -dp %{buildroot}%{_bindir}
install -p -m 755 ./bin/crictl %{buildroot}%{_bindir}

# install manpage
install -dp %{buildroot}%{_mandir}/man1
install -p -m 644 docs/crictl.1 %{buildroot}%{_mandir}/man1

# install completions
install -dp %{buildroot}%{_datadir}/bash-completion/completions/
install -p -m 644 docs/crictl-completions %{buildroot}%{_datadir}/bash-completion/completions/crictl

%check

#define license tag if not already defined
%{!?_licensedir:%global license %doc}

%files
%license LICENSE
%doc CHANGELOG.md CONTRIBUTING.md OWNERS README.md RELEASE.md code-of-conduct.md
%doc docs/{benchmark.md,roadmap.md,validation.md}
%{_bindir}/crictl
%{_mandir}/man1/crictl*
%{_datadir}/bash-completion/completions/crictl

%changelog
* Mon Apr 15 2024 AOS Automation Release Team <aos-team-art@redhat.com> - 1.28.0-3.2
Bump and rebuild with latest golang, resolves ART-9397

* Thu Mar 21 2024 AOS Automation Release Team <aos-team-art@redhat.com> - 1.28.0-3.1
Bump and rebuild with latest golang, resolves ART-9185

* Fri Jan 26 2024 Peter Hunt <pehunt@redhat.com> - 1.28.0-3
- add snyk file

* Thu Jan 25 2024 Peter Hunt <pehunt@redhat.com> - 1.28.0-2
- bump and rebuild with latest golang
- remove golang provides statements, as they're out of date

* Thu Oct 19 2023 Siddharth Sharma <sidsharm@redhat.com> - 1.28.0-1
Bump and rebuild with latest golang, resolves ART-7951

* Thu Sep 07 2023 Sascha Grunert <sgrunert@redhat.com> - 1.28.0-1
- Bump to v1.28.0

* Fri Dec 16 2022 Peter Hunt~ <pehunt@redhat.com> - 1.26.0-1
- bump to v1.26.0

* Mon Aug 29 2022 Sascha Grunert <sgrunert@redhat.com> - 1.25.0-1
- Bump to v1.25.0

* Mon Aug 08 2022 Peter Hunt~ <pehunt@redhat.com> - 1.24.2-5
- rebuild for golang CVE-2021-38561

* Thu Jun 09 2022 Sascha Grunert <sgrunert@redhat.com> - 1.24.2-4
- Bump to v1.24.2

* Thu May 05 2022 Sascha Grunert <sgrunert@redhat.com> - 1.24.0-2
- Bump to v1.24.0

* Fri Aug 06 2021 Sascha Grunert <sgrunert@redhat.com> - 1.22.0-1
- Bump to v1.22.0

* Mon Apr 12 2021 Sascha Grunert <sgrunert@redhat.com> - 1.21.0-2
- Bump to v1.21.0

* Wed Jan 13 2021 Peter Hunt <pehunt@redhat.com> - 1.20.0-1
- bump to 1.20.0

* Mon Nov 23 2020 Jindrich Novy <jnovy@redhat.com> - 1.19.0-4
- fix gobuild macro

* Mon Nov 23 2020 Jindrich Novy <jnovy@redhat.com> - 1.19.0-3
- fix CGO_CFLAGS

* Thu Nov 19 2020 Peter Hunt <pehunt@redhat.com> - 1.19.0-2
- Improve CGO_FLAGS and LDFLAGS handling

* Wed Nov 18 2020 Peter Hunt <pehunt@redhat.com> - 1.19.0-1
- Add CGO_FLAGS and better harden LD_FLAGS

* Tue Nov 10 2020 Peter Hunt <pehunt@redhat.com> - 1.19.0-0
- bump to v1.19.0

* Wed May 27 2020 Peter Hunt <pehunt@redhat.com> - 1.18.0-3
- Resolves: #1704661 add crictl completions

* Wed May 27 2020 Peter Hunt <pehunt@redhat.com> - 1.18.0-2
- Resolves: #1752907 fixed crictl --version

* Thu May 21 2020 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.18.0-1
- bump to v1.18.0

* Tue Feb 18 2020 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.17.0-2
- enable debuginfo

* Tue Feb 11 2020 Lokesh Mandvekar <lsm5@redhat.com> - 1.17.0-1
- bump tov v1.17.0

* Wed Oct 09 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.16.1-1.rhaos4.2
- bump to v1.16.1
- build without no_openssl tag

* Thu Jun 27 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.14.0-1.rhaos4.2
- bump to v1.14.0

* Tue Apr 30 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.13.0-2.rhaos4.1.gitb69a0b9
- built commit b69a0b9

* Wed Feb 27 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.13.0-1.rhaos4.1.gitc06001f
- first build for OCP 4.1 on rhel8

* Thu Jan 24 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.12.0-3.rhaos4.0.git5a01d85
- Resolves: #166358 - timeout quick if user isn't root

* Wed Jan 23 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.12.0-2.rhaos4.0.git5a01d85
- Resolves: #1666358 - complain if user isn't root

* Thu Oct 25 2018 Lokesh Mandvekar <lsm5@redhat.com> - 1.12.0-1.rhaos4.0.git5a01d85
- bump to v1.12.0
- built for all available arches

* Fri Sep 14 2018 Lokesh Mandvekar <lsm5@redhat.com> - 1.11.1-1.rhaos3.11.gitedabfb5
- built release-1.11 commit edabfb5
- use correct version number

* Mon Jul 02 2018 Lokesh Mandvekar <lsm5@redhat.com> - 1.0.0-6.rhaos3.11.git78ec590
- import spec from rhaos3.10
- built release-1.11 commit 78ec590

* Wed May 16 2018 Lokesh Mandvekar <lsm5@redhat.com> - 1.0.0-5.rhaos3.10.git2e22a75
- Resolves: #1572795 - build for all arches
- From: Yaakov Selkowitz <yselkowi@redhat.com>

* Tue May 15 2018 Lokesh Mandvekar <lsm5@redhat.com> - 1.0.0-4.rhaos3.10.git2e22a75
- built commit 2e22a75
- include rhaos version in release tag

* Sun Apr 22 2018 Lokesh Mandvekar <lsm5@redhat.com> - 1.0.0-3.gitf37a5a1
- built commit f37a5a1
- critest doesn't build, skipped for now

* Wed Feb 07 2018 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.0.0-2.alpha.0.git653cc8c
- include critest binary

* Wed Feb 07 2018 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.0.0-1.alpha.0.gitf1a58d6
- First package for Fedora
